@@ -62,8 +62,9 @@ class AttachmentInline(admin.TabularInline):
 
 @admin.register(NotificationEvent)
 class NotificationEventAdmin(admin.ModelAdmin):
-    list_display = ['id', 'title', 'owner', 'smtp_provider', 'template', 'is_active', 'created_time', 'updated_time']
-    list_filter = ['is_active', 'created_time', 'updated_time']
+    list_display = ['id', 'title', 'owner', 'smtp_provider', 'template', 'is_active', 'is_sent', 'sent_time',
+                    'created_time', 'updated_time']
+    list_filter = ['is_active', 'sent_time', 'created_time', 'updated_time']
     filter_horizontal = ['recipients', 'notification_groups']
     raw_id_fields = ['owner', 'smtp_provider', 'template']
     readonly_fields = ['created_time', 'updated_time']
