@@ -58,7 +58,7 @@ class NotificationEventSerializer(serializers.ModelSerializer):
     notification_groups_detail = MinimalNotificationGroupSerializer(source='notification_groups', many=True,
                                                                     read_only=True)
     recipients = serializers.PrimaryKeyRelatedField(many=True, queryset=User.objects.filter(is_active=True),
-                                                    required=False)
+                                                    required=False, write_only=True)
 
     class Meta:
         model = NotificationEvent
@@ -141,8 +141,7 @@ class NotificationEventDetailSerializer(serializers.ModelSerializer):
                                                             read_only=True)
     notification_groups_detail = MinimalNotificationGroupSerializer(source='notification_groups', many=True,
                                                                     read_only=True)
-    recipients = serializers.PrimaryKeyRelatedField(many=True, queryset=User.objects.filter(is_active=True),
-                                                    required=False)
+    total_count = serializers.IntegerField(read_only=True, default=0)
     sent_status_count = serializers.IntegerField(read_only=True, default=0)
     pending_status_count = serializers.IntegerField(read_only=True, default=0)
     failed_status_count = serializers.IntegerField(read_only=True, default=0)
@@ -161,7 +160,7 @@ class NotificationEventDetailSerializer(serializers.ModelSerializer):
         model = NotificationEvent
         fields = ['id', 'title', 'smtp_provider_detail', 'template_detail', 'subject', 'content',
                   'notification_event_type', 'notification_event_type_display', 'notification_groups_detail',
-                  'attachments', 'recipients', 'is_sent', 'sent_time', 'created_time', 'updated_time',
+                  'attachments', 'is_sent', 'sent_time', 'created_time', 'updated_time', 'total_count',
                   'sent_status_count', 'pending_status_count', 'failed_status_count', 'bounce_status_count',
                   'complaint_status_count', 'delivery_status_count', 'amazon_send_status_count', 'reject_status_count',
                   'open_status_count', 'click_status_count', 'rendering_failure_status_count',
